DPDK patches and discussions
 help / color / mirror / Atom feed
* [dpdk-dev] [PATCH] bonding: fix lacp negotiation failed
@ 2019-03-13 13:23 Liang Zhang
  2019-03-13 18:02 ` Chas Williams
  2019-03-14 12:09 ` [dpdk-dev] [PATCH v2] " Liang Zhang
  0 siblings, 2 replies; 10+ messages in thread
From: Liang Zhang @ 2019-03-13 13:23 UTC (permalink / raw)
  To: dev; +Cc: Liang Zhang

When monitor(port-mirroring) traffic from other lacp port-channel,
rx_machine_update may recieving other lacp negotiation packets.
Thus bond mode 4 will negotiation failed.

Signed-off-by: Liang Zhang <zhangliang@bigo.sg>
---
 drivers/net/bonding/rte_eth_bond_8023ad.c         | 9 +++++++--
 drivers/net/bonding/rte_eth_bond_8023ad_private.h | 1 +
 2 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/drivers/net/bonding/rte_eth_bond_8023ad_private.h b/drivers/net/bonding/rte_eth_bond_8023ad_private.h
index c51426b..f91902e 100644
--- a/drivers/net/bonding/rte_eth_bond_8023ad_private.h
+++ b/drivers/net/bonding/rte_eth_bond_8023ad_private.h
@@ -150,6 +150,7 @@ struct mode8023ad_private {
 	uint64_t update_timeout_us;
 	rte_eth_bond_8023ad_ext_slowrx_fn slowrx_cb;
 	uint8_t external_sm;
+	struct ether_addr mac_addr;
 
 	struct rte_eth_link slave_link;
 	/***< slave link properties */
diff --git a/drivers/net/bonding/rte_eth_bond_8023ad.c b/drivers/net/bonding/rte_eth_bond_8023ad.c
index dd847c6..e518956 100644
--- a/drivers/net/bonding/rte_eth_bond_8023ad.c
+++ b/drivers/net/bonding/rte_eth_bond_8023ad.c
@@ -784,13 +784,17 @@ static void
 rx_machine_update(struct bond_dev_private *internals, uint8_t slave_id,
 		struct rte_mbuf *lacp_pkt) {
 	struct lacpdu_header *lacp;
+	struct lacpdu_actor_partner_params *partner;
 
 	if (lacp_pkt != NULL) {
 		lacp = rte_pktmbuf_mtod(lacp_pkt, struct lacpdu_header *);
 		RTE_ASSERT(lacp->lacpdu.subtype == SLOW_SUBTYPE_LACP);
 
-		/* This is LACP frame so pass it to rx_machine */
-		rx_machine(internals, slave_id, &lacp->lacpdu);
+		partner = &lacp->lacpdu.partner;
+		if (is_same_ether_addr(&partner->port_params.system, &internals->mode4.mac_addr)) {
+			/* This is LACP frame to the bonding port so pass it to rx_machine */
+			rx_machine(internals, slave_id, &lacp->lacpdu);
+		}
 		rte_pktmbuf_free(lacp_pkt);
 	} else
 		rx_machine(internals, slave_id, NULL);
@@ -1140,6 +1144,7 @@ bond_mode_8023ad_setup(struct rte_eth_dev *dev,
 	bond_mode_8023ad_conf_assign(mode4, conf);
 	mode4->slowrx_cb = conf->slowrx_cb;
 	mode4->agg_selection = AGG_STABLE;
+	rte_eth_macaddr_get(internals->port_id, &mode4->mac_addr);
 
 	if (dev->data->dev_started)
 		bond_mode_8023ad_start(dev);
-- 
2.7.4

^ permalink raw reply	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2019-03-15  8:54 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-03-13 13:23 [dpdk-dev] [PATCH] bonding: fix lacp negotiation failed Liang Zhang
2019-03-13 18:02 ` Chas Williams
2019-03-14 12:27   ` [dpdk-dev] [PATCH v2] bonding: change mac_addr filled position Liang Zhang
2019-03-14 12:27     ` Liang Zhang
2019-03-15  8:53     ` [dpdk-dev] [PATCH v3 1/2] bonding: fix lacp negotiation failed Liang Zhang
2019-03-15  8:53       ` Liang Zhang
2019-03-15  8:53       ` [dpdk-dev] [PATCH v3 2/2] bonding: change mac_addr filled position Liang Zhang
2019-03-15  8:53         ` Liang Zhang
2019-03-14 12:09 ` [dpdk-dev] [PATCH v2] " Liang Zhang
2019-03-14 12:09   ` Liang Zhang

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).